package IndustrialRobot "Example that demonstrates robot system models based on the Manutec r3 robot."
  import SI = Modelica.SIunits;

  package Components "Library of components of the robot"
    extends Modelica.Icons.Package;

    model MechanicalStructure "Model of the mechanical part of the r3 robot (without animation)"
      parameter Boolean animation = true "= true, if animation shall be enabled";
      parameter SI.Mass mLoad(min = 0) = 15 "Mass of load";
      parameter SI.Position rLoad[3] = {0, 0.25, 0} "Distance from last flange to load mass>";
      parameter SI.Acceleration g = 9.81 "Gravity acceleration";
      SI.Angle q[6] "Joint angles";
      SI.AngularVelocity qd[6] "Joint speeds";
      SI.AngularAcceleration qdd[6] "Joint accelerations";
      SI.Torque tau[6] "Joint driving torques";
      Modelica.Mechanics.Rotational.Interfaces.Flange_a axis1 annotation(Placement(transformation(extent = {{-220, -180}, {-200, -160}}, rotation = 0, origin = {0, 50}), visible = true, iconTransformation(origin = {0, 20}, extent = {{-220, -180}, {-200, -160}}, rotation = 0)));
      Modelica.Mechanics.Rotational.Interfaces.Flange_a axis2 annotation(Placement(transformation(extent = {{-220, -120}, {-200, -100}}, rotation = 0, origin = {0, 30}), visible = true, iconTransformation(origin = {0, 20}, extent = {{-220, -120}, {-200, -100}}, rotation = 0)));
      Modelica.Mechanics.Rotational.Interfaces.Flange_a axis3 annotation(Placement(transformation(extent = {{-220, -60}, {-200, -40}}, rotation = 0, origin = {0, 10}), visible = true, iconTransformation(origin = {0, 20}, extent = {{-220, -60}, {-200, -40}}, rotation = 0)));
      Modelica.Mechanics.Rotational.Interfaces.Flange_a axis4 annotation(Placement(transformation(extent = {{-220, 0}, {-200, 20}}, rotation = 0, origin = {0, 30}), visible = true, iconTransformation(origin = {0, 20}, extent = {{-220, 0}, {-200, 20}}, rotation = 0)));
      Modelica.Mechanics.Rotational.Interfaces.Flange_a axis5 annotation(Placement(transformation(extent = {{-220, 60}, {-200, 80}}, rotation = 0, origin = {0, 10}), visible = true, iconTransformation(origin = {0, 20}, extent = {{-220, 60}, {-200, 80}}, rotation = 0)));
      Modelica.Mechanics.Rotational.Interfaces.Flange_a axis6 annotation(Placement(transformation(extent = {{-220, 120}, {-200, 140}}, rotation = 0, origin = {0, -10}), visible = true, iconTransformation(origin = {0, 20}, extent = {{-220, 120}, {-200, 140}}, rotation = 0)));
      inner Modelica.Mechanics.MultiBody.World world(g = g * Modelica.Math.Vectors.length({0, -1, 0}), animateWorld = false, animateGravity = false, enableAnimation = animation) annotation(Placement(transformation(extent = {{20, -20}, {-20, 20}}, rotation = 0, origin = {100, -161.567}), visible = true));
      Modelica.Mechanics.MultiBody.Joints.Revolute r1(n = {0, 1, 0}, useAxisFlange = true, animation = animation) annotation(Placement(transformation(origin = {-60, -120}, extent = {{-10, -10}, {10, 10}}, rotation = 90), visible = true));
      Modelica.Mechanics.MultiBody.Joints.Revolute r2(n = {1, 0, 0}, useAxisFlange = true, animation = animation) annotation(Placement(transformation(extent = {{-10, -10}, {10, 10}}, rotation = -270, origin = {0, -80}), visible = true));
      Modelica.Mechanics.MultiBody.Joints.Revolute r3(n = {1, 0, 0}, useAxisFlange = true, animation = animation) annotation(Placement(transformation(origin = {60, -40}, extent = {{-10, -10}, {10, 10}}, rotation = 90), visible = true));
      Modelica.Mechanics.MultiBody.Joints.Revolute r4(n = {0, 1, 0}, useAxisFlange = true, animation = animation) annotation(Placement(transformation(origin = {60, 40}, extent = {{-10, -10}, {10, 10}}, rotation = 90), visible = true));
      Modelica.Mechanics.MultiBody.Joints.Revolute r5(n = {1, 0, 0}, useAxisFlange = true, animation = animation) annotation(Placement(transformation(extent = {{-10, -10}, {10, 10}}, rotation = -270, origin = {0, 80}), visible = true));
      Modelica.Mechanics.MultiBody.Joints.Revolute r6(n = {0, 1, 0}, useAxisFlange = true, animation = animation) annotation(Placement(transformation(origin = {-60, 120}, extent = {{-10, -10}, {10, 10}}, rotation = 90), visible = true));
      Modelica.Mechanics.MultiBody.Parts.BodyShape b0(r = {0, 0.351, 0}, shapeType = "modelica://IndustrialRobot/DocumentationFiles/0.dxf", r_shape = {0, 0, 0}, lengthDirection = {1, 0, 0}, widthDirection = {0, 1, 0}, length = 0.225, width = 0.3, height = 0.3, color = {0, 0, 255}, animation = animation, animateSphere = false, r_CM = {0, 0, 0}, m = 1) annotation(Placement(transformation(origin = {-30, -160}, extent = {{-10, -10}, {10, 10}}, rotation = -180), visible = true));
      Modelica.Mechanics.MultiBody.Parts.BodyShape b1(r = {0, 0.324, 0.3}, I_22 = 1.16, shapeType = "modelica://IndustrialRobot/DocumentationFiles/1.dxf", lengthDirection = {1, 0, 0}, widthDirection = {0, 1, 0}, length = 0.25, width = 0.15, height = 0.2, animation = animation, animateSphere = false, color = {255, 0, 0}, r_CM = {0, 0, 0}, m = 1) annotation(Placement(transformation(origin = {-30, -100}, extent = {{-10, -10}, {10, 10}}, rotation = 0), visible = true));
      Modelica.Mechanics.MultiBody.Parts.BodyShape b2(r = {0, 0.65, 0}, r_CM = {0.172, 0.205, 0}, m = 56.5, I_11 = 2.58, I_22 = 0.64, I_33 = 2.73, I_21 = -0.46, shapeType = "modelica://IndustrialRobot/DocumentationFiles/2.dxf", r_shape = {0, 0, 0}, lengthDirection = {1, 0, 0}, widthDirection = {0, 1, 0}, length = 0.5, width = 0.2, height = 0.15, animation = animation, animateSphere = false, color = {255, 178, 0}) annotation(Placement(transformation(origin = {30, -60}, extent = {{-10, -10}, {10, 10}}, rotation = 0), visible = true));
      Modelica.Mechanics.MultiBody.Parts.BodyShape b3(r = {0, 0.414, -0.155}, r_CM = {0.064, -0.034, 0}, m = 26.4, I_11 = 0.279, I_22 = 0.245, I_33 = 0.413, I_21 = -0.07, shapeType = "modelica://IndustrialRobot/DocumentationFiles/3.dxf", r_shape = {0, 0, 0}, lengthDirection = {1, 0, 0}, widthDirection = {0, 1, 0}, length = 0.15, width = 0.15, height = 0.15, animation = animation, animateSphere = false, color = {255, 0, 0}) annotation(Placement(transformation(origin = {60, 0}, extent = {{-10, 10}, {10, -10}}, rotation = 90), visible = true));
      Modelica.Mechanics.MultiBody.Parts.BodyShape b4(r = {0, 0.186, 0}, r_CM = {0, 0, 0}, m = 28.7, I_11 = 1.67, I_22 = 0.081, I_33 = 1.67, shapeType = "modelica://IndustrialRobot/DocumentationFiles/4.dxf", r_shape = {0, 0, 0}, lengthDirection = {1, 0, 0}, widthDirection = {0, 1, 0}, length = 0.73, width = 0.1, height = 0.1, animation = animation, animateSphere = false, color = {255, 178, 0}) annotation(Placement(transformation(origin = {30, 60}, extent = {{-10, -10}, {10, 10}}, rotation = -180), visible = true));
      Modelica.Mechanics.MultiBody.Parts.BodyShape b5(r = {0, 0.125, 0}, r_CM = {0, 0, 0}, m = 5.2, I_11 = 1.25, I_22 = 0.81, I_33 = 1.53, r_shape = {0, 0, 0}, lengthDirection = {1, 0, 0}, widthDirection = {0, 1, 0}, length = 0.225, width = 0.075, height = 0.1, animation = animation, animateSphere = false, color = {0, 0, 255}, shapeType = "modelica://IndustrialRobot/DocumentationFiles/5.dxf") annotation(Placement(transformation(origin = {-30, 100}, extent = {{-10, -10}, {10, 10}}, rotation = -180), visible = true));
      Modelica.Mechanics.MultiBody.Parts.BodyShape b6(r = {0, 0, 0}, r_CM = {0.05, 0.05, 0.05}, m = 0.5, shapeType = "modelica://IndustrialRobot/DocumentationFiles/6.dxf", r_shape = {0, 0, 0}, lengthDirection = {1, 0, 0}, widthDirection = {0, 1, 0}, animation = animation, animateSphere = false, color = {0, 0, 255}) annotation(Placement(transformation(origin = {-60, 150}, extent = {{-10, -10}, {10, 10}}, rotation = 90), visible = true));
      Modelica.Mechanics.MultiBody.Parts.BodyShape load(r_CM = rLoad, m = mLoad, r_shape = {0, 0, 0}, widthDirection = {1, 0, 0}, width = 0.05, height = 0.05, color = {255, 0, 0}, lengthDirection = rLoad, length = Modelica.Math.Vectors.length(rLoad), animation = animation) annotation(Placement(transformation(origin = {-60, 180}, extent = {{-10, -10}, {10, 10}}, rotation = 90), visible = true));
      Modelica.Mechanics.MultiBody.Parts.FixedTranslation toA(r = {0.15, 0.0, 1.0}, height = 0.1, width = 0.1) annotation(Placement(visible = true, transformation(origin = {90, -80}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Mechanics.MultiBody.Parts.FixedTranslation toB(r = {1.34, 0, -0.95}, height = 0.1, width = 0.1) annotation(Placement(visible = true, transformation(origin = {90, -120}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Mechanics.MultiBody.Parts.FixedTranslation toA1(height = 0.1, r = {0, 0.3, 0}, width = 0.1) annotation(Placement(visible = true, transformation(origin = {120, -30}, extent = {{-10, -10}, {10, 10}}, rotation = -270)));
      Modelica.Mechanics.MultiBody.Parts.BodyBox bodyBox2(color = {100, 200, 300}, height = 0.5, length = 0.3, r = {0, 0, 0}, r_shape = {-0.15, 0.0, 0.0}, width = 0.05) annotation(Placement(visible = true, transformation(origin = {120, -0}, extent = {{-10, -10}, {10, 10}}, rotation = -270)));
      Modelica.Mechanics.MultiBody.Parts.FixedTranslation toB1(height = 0.1, r = {0.0, 1.5, 0.0}, width = 0.1) annotation(Placement(visible = true, transformation(origin = {180, 30}, extent = {{-10, -10}, {10, 10}}, rotation = -270)));
      Modelica.Mechanics.MultiBody.Parts.BodyBox bodyBox3(color = {155, 200, 0}, height = 0.5, length = 0.3, r_shape = {-0.15, 0, 0}, width = 0.05) annotation(Placement(visible = true, transformation(origin = {180, 60}, extent = {{-10, -10}, {10, 10}}, rotation = -270)));
      Modelica.Mechanics.MultiBody.Parts.Fixed Origin annotation(Placement(visible = true, transformation(origin = {-54.249, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Mechanics.MultiBody.Visualizers.FixedShape GroundVisualizer(shapeType = "modelica://IndustrialRobot/DocumentationFiles/floor.obj", height = 1, length = 1, width = 1, widthDirection = {0, 0, 1}, r_shape = {-3, 0, 0}) annotation(Placement(visible = true, transformation(origin = {-10, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    equation
      connect(Origin.frame_b, GroundVisualizer.frame_a) annotation(Line(visible = true, origin = {-32.125, 0}, points = {{-12.124, 0}, {12.125, 0}}, color = {95, 95, 95}));
      connect(toB1.frame_a, toB.frame_b) annotation(Line(visible = true, origin = {153.333, -73.333}, points = {{26.667, 93.333}, {26.667, -46.667}, {-53.333, -46.667}}, color = {95, 95, 95}));
      connect(toB.frame_a, world.frame_b) annotation(Line(visible = true, origin = {41.625, -140.784}, points = {{38.375, 20.784}, {-1.625, 20.784}, {-1.625, -20.784}, {38.375, -20.783}}, color = {95, 95, 95}));
      connect(bodyBox3.frame_a, toB1.frame_b) annotation(Line(visible = true, origin = {180, 45}, points = {{0, 5}, {0, -5}}, color = {95, 95, 95}));
      connect(bodyBox2.frame_a, toA1.frame_b) annotation(Line(visible = true, origin = {120, -15}, points = {{0, 5}, {0, -5}}, color = {95, 95, 95}));
      connect(toA1.frame_a, toA.frame_b) annotation(Line(visible = true, origin = {113.333, -66.667}, points = {{6.667, 26.667}, {6.667, -13.333}, {-13.333, -13.333}}, color = {95, 95, 95}));
      connect(toA.frame_a, world.frame_b) annotation(Line(visible = true, origin = {41.625, -120.784}, points = {{38.375, 40.784}, {-1.625, 40.784}, {-1.625, -40.784}, {38.375, -40.783}}, color = {95, 95, 95}));
      connect(b4.frame_b, r5.frame_a) annotation(Line(visible = true, origin = {6.667, 63.333}, points = {{13.333, -3.333}, {-6.667, -3.333}, {-6.667, 6.667}}, color = {95, 95, 95}, thickness = 0.5));
      connect(r4.frame_b, b4.frame_a) annotation(Line(visible = true, origin = {53.333, 56.667}, points = {{6.667, -6.667}, {6.667, 3.333}, {-13.333, 3.333}}, color = {95, 95, 95}, thickness = 0.5));
      connect(r6.frame_b, b6.frame_a) annotation(Line(points = {{0, -5}, {0, 5}}, color = {95, 95, 95}, thickness = 0.5, visible = true, origin = {-60, 135}));
      q = {r1.phi, r2.phi, r3.phi, r4.phi, r5.phi, r6.phi};
      qd = der(q);
      qdd = der(qd);
      tau = {r1.axis.tau, r2.axis.tau, r3.axis.tau, r4.axis.tau, r5.axis.tau, r6.axis.tau};
      connect(load.frame_a, b6.frame_b) annotation(Line(points = {{0, 5}, {0, -5}}, color = {95, 95, 95}, thickness = 0.5, visible = true, origin = {-60, 165}));
      connect(world.frame_b, b0.frame_a) annotation(Line(points = {{73.494, -0.783}, {-23.494, -0.784}, {-23.494, 0.784}, {-26.506, 0.784}}, color = {95, 95, 95}, thickness = 0.5, visible = true, origin = {6.506, -160.784}));
      connect(b0.frame_b, r1.frame_a) annotation(Line(points = {{13.333, -10}, {-6.667, -10}, {-6.667, 20}}, color = {95, 95, 95}, thickness = 0.5, visible = true, origin = {-53.333, -150}));
      connect(b1.frame_b, r2.frame_a) annotation(Line(points = {{-13.333, -3.333}, {6.667, -3.333}, {6.667, 6.667}}, color = {95, 95, 95}, thickness = 0.5, visible = true, origin = {-6.667, -96.667}));
      connect(r1.frame_b, b1.frame_a) annotation(Line(points = {{-6.667, -6.667}, {-6.667, 3.333}, {13.333, 3.333}}, color = {95, 95, 95}, thickness = 0.5, visible = true, origin = {-53.333, -103.333}));
      connect(r2.frame_b, b2.frame_a) annotation(Line(points = {{-6.667, -6.667}, {-6.667, 3.333}, {13.333, 3.333}}, color = {95, 95, 95}, thickness = 0.5, visible = true, origin = {6.667, -63.333}));
      connect(b2.frame_b, r3.frame_a) annotation(Line(points = {{-13.333, -3.333}, {6.667, -3.333}, {6.667, 6.667}}, color = {95, 95, 95}, thickness = 0.5, visible = true, origin = {53.333, -56.667}));
      connect(r2.axis, axis2) annotation(Line(points = {{100, 0}, {-100, 0}}, visible = true, origin = {-110, -80}, color = {64, 64, 64}));
      connect(r1.axis, axis1) annotation(Line(points = {{70, 0}, {-70, 0}}, visible = true, origin = {-140, -120}, color = {64, 64, 64}));
      connect(r3.frame_b, b3.frame_a) annotation(Line(points = {{0, -10}, {0, 10}}, color = {95, 95, 95}, thickness = 0.5, visible = true, origin = {60, -20}));
      connect(b3.frame_b, r4.frame_a) annotation(Line(points = {{0, -10}, {0, 10}}, color = {95, 95, 95}, thickness = 0.5, visible = true, origin = {60, 20}));
      connect(r3.axis, axis3) annotation(Line(points = {{130, 0}, {-130, 0}}, visible = true, origin = {-80, -40}, color = {64, 64, 64}));
      connect(r4.axis, axis4) annotation(Line(points = {{130, 0}, {-130, 0}}, visible = true, origin = {-80, 40}, color = {64, 64, 64}));
      connect(r5.axis, axis5) annotation(Line(points = {{100, 0}, {-100, 0}}, visible = true, origin = {-110, 80}, color = {64, 64, 64}));
      connect(r5.frame_b, b5.frame_a) annotation(Line(points = {{6.667, -6.667}, {6.667, 3.333}, {-13.333, 3.333}}, color = {95, 95, 95}, thickness = 0.5, visible = true, origin = {-6.667, 96.667}));
      connect(b5.frame_b, r6.frame_a) annotation(Line(points = {{13.333, -3.333}, {-6.667, -3.333}, {-6.667, 6.667}}, color = {95, 95, 95}, thickness = 0.5, visible = true, origin = {-53.333, 103.333}));
      connect(r6.axis, axis6) annotation(Line(points = {{70, 0}, {-70, 0}}, visible = true, origin = {-140, 120}, color = {64, 64, 64}));
      annotation(Documentation(info = "<html><!--WSMINSERTIONTAGSTART MechanicalStructure -->
   <head>
   <style type=\"text/css\">
   
  body {
   padding: 0px;
   margin: 0px;
  }
  
  a {
   color: #cf1d24;
  }
  
  a.target {
   padding-top: 40px;
   margin-top: -40px;
  }
  
  p {
   font-family: arial;
   font-size: 13;
   margin: 9px 40px 5px 40px;
   padding-bottom: 0px;
   color: #555555;
   max-width: 800px;
  }
  
  h1 {
   font-size: 30;
   color: #cf1d24;
   font-weight: bold;
   margin-left: 20px;
   margin-top: 32px;
   margin-bottom: 15px;
   margin-right: 20px;
   padding-top: 0px;
  }
  
  h2 {
   font-size: 20;
   color: #cf1d24;
   font-weight: bold;
   margin-left: 20px;
   margin-right: 20px;
   margin-top: 5px;
   margin-bottom: 9px;
  }
  
  h3 {
   background: url('DocumentationFiles/dingbat3.png') no-repeat 0 0;
   font-size: 14px;
   font-family: helvetica;
   color: #4B4B4B;
   font-weight: bold;
   padding-left: 18px;
   margin-left: 20px;
   margin-right: 20px;
   margin-top: 12px;
   margin-bottom: 8px;
  }
  
  ul {
   font-family: arial;
   font-size: 13;
   margin: 9px 40px 5px 40px;
   padding-bottom: 0px;
   color: #555555;
   max-width: 800px;
   list-style-type: square;
  }
  
  li {
   margin-left: 0px;
   margin-top: 4px;
   margin-bottom: 2px;
   padding-left: 0px;
  }

  div.header {
   background: url('DocumentationFiles/WSMLogo.png') no-repeat 0 0;
   height: 96px;
   margin-top: 35px;
   background-color: #871613;
  }
  
  .headerspan {
   font-family: arial;
   text-decoration: none;
   font-size: 12px;
   font-weight: bold;
   display: inline-block;
   height: 35px;
   color: gray;
   padding: 0px;
   margin: 0px;
   margin-left: 20px;
  }
  
  .headera {
   font-family: arial;
   text-decoration: none;
   font-size: 12px;
   font-weight: bold;
   padding: 0px;
   color: inherit;
   vertical-align: middle;
   margin: 0px;
  }
  
  .headerlinkdiv {
   background: black;
   padding: 0px;
   height: 35px;
   margin: 0px;
   position: fixed; top: 0px; left: 0px; width: 100%;
  }
  
  .contenttable {
   -webkit-box-shadow: 3px 3px 3px #DDDDDD;
   border-top: 3px solid #cf1d24;
   background: #f9f9f9;
   max-width: 500px;
   margin: 15px 15px 0px 20px;
   padding: 6px 10px 3px 10px;
  }
  
  .contenttableheader {
   color: #a4a4a4;
   font-size: 14px;
   font-family: arial;
  }
  
  .contenttabletable {
   border: 0px solid #FFFFFF;
   padding: 0px;
   padding-left: 20px;
  }
  
  .contenttable tr td {
   padding: 3px;
   min-width: 200px;
  }
  
  .contenttable tr td a {
   color: #555555;
   text-decoration: none;
   font-size: 13px;
   font-family: arial;
  }
  
  .hacek {
   color: #cf1d24;
   font-size: 25px;
   font-weight: plain;
   vertical-align: -40%;
  }
  
  .mathematicapointerwrapper {
   border: 0px solid #DDDDDD;
   margin: 15px 15px 15px 40px;
   padding: 0px;
   max-width: 500px;
  }
  
  .mathematicapointertop {
   border: 1px solid #DDDDDD;
   background-color: #F2F2F2;
   padding: 0px;
   max-width: 500px;
   height: 4px;
  }
  
  .mathematicapointerdiv {
   background: url('./DocumentationFiles/mathematicabook.png') no-repeat  left center;
   border: 1px solid #DDDDDD;
   background-color: #FFFFFF;
   margin: 0px;
   padding: 15px 9px 9px 89px;
   max-width: 500px;
   min-height: 67px;
  }
  
  p.mathematicapointer {
   padding: 0px;
   margin: 0px;
   font-size: 12px;
  }
  
  .infoboxwrapper {
   border: 0px solid #DDDDDD;
   -webkit-box-shadow: 3px 3px 3px #DDDDDD;
   margin: 15px 15px 15px 40px;
   padding: 0px;
   max-width: 500px;
  }
  
  .infoboxtop {
   background: url('./DocumentationFiles/infotick.png') no-repeat left center;
   border: 1px solid #DDDDDD;
   background-color: #F2F2F2;
   padding: 0px;
   max-width: 500px;
   height: 37px;
  }
  
  div.infobox {
   border: 1px solid #DDDDDD;
   background-color: #FFFFFF;
   margin: 0px;
   padding: 15px;
   max-width: 500px;
  }
  
  p.infobox {
   padding: 0px;
   margin: 0px;
   font-size: 12px;
  }
  
  h2.legal {
   font-family: arial;
   font-size: 14;
   color: #cf1d24;
   margin: 15px 15px 15px 20px;
   font-weight: bold;
  }
  
  h3.legal {
   background: url('./DocumentationFiles/dingbat3.png') no-repeat 0 0;
   font-family: arial;
   font-size: 12;
   color: #808080;
   margin-left: 38px;
   padding-left: 12px;
   font-weight: bold;
  }
  
  ul.legal {
   font-size: 10px;
   font-family: arial;
   color: #555555;
   margin-left: 28px;
  }
  
  ul.legal li {
   margin-left: 0px;
   margin-top: 4px;
   margin-bottom: 2px;
   padding-left: 0px;
  }

  ul.imgbullets li {
   margin-left: -40px;
   margin-top: 4px;
   margin-bottom: 10px;
   padding-left: 30px;
   list-style-type: none;
  }
  
  p.legallarge {
   font-size: 12px;
   margin-left: 38px;
  }
  
  p.legalsmall {
   font-size: 11px;
   margin-left: 38px;
   padding-left: 12px;
  }
  
  .legalend {
   height: 10px;
  }
  
  .variablename {
   font-family: Courier New, Courier;
  }
  
  .dialogelement {
   font-weight: bold;
  }
  
  .menuitem {
   font-weight: bold;
  }
  
  .mr {
   font-family: Courier New, Courier;
  }
  
  .ttable {
	border-collapse: collapse;
    width: 100%;
	}

	.ttable td, th {
    border: 1px solid #dddddd;
    text-align: left;
	padding: 8px;
	}

	.ttable tr:nth-child(even) {
		background-color: #dddddd;
	}
  
   </style>
   </head>
   <body>
   
  <div class=\"headerlinkdiv\">
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/examples.png) no-repeat 0 0;
   padding-left: 24px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/examples_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/examples.png) no-repeat 0 0';
   \"><a href=\"https://www.wolfram.com/system-modeler/examples/\" class=\"headera\">More Examples</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/video.png) no-repeat 0 0;
   padding-left: 29px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/video_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/video.png) no-repeat 0 0';
   \"><a href=\"http://www.wolfram.com/system-modeler/resources/get-started/\" class=\"headera\">Introductory Videos</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/docs.png) no-repeat 0 0;
   padding-left: 20px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/docs_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/docs.png) no-repeat 0 0';
   \"><a href=\"http://reference.wolfram.com/system-modeler\" class=\"headera\">Documentation</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/contact.png) no-repeat 0 0;
   padding-left: 24px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/contact_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/contact.png) no-repeat 0 0';
   \"><a href=\"http://www.wolfram.com/system-modeler/contact-us/\" class=\"headera\">Contact Us</a></span>
  </div> <div class=\"header\">&nbsp;</div> <h1>Industrial Robot: Mechanical Structure</h1><a id=\"headerTag_Description\" class=\"target\">&nbsp;</a>
    <h2>Description</h2>
    <p class=\"\">
This model contains the mechanical parts of the industrial robot. It is a modified version of <a href=\"modelica://Modelica.Mechanics.MultiBody.Examples.Systems.RobotR3.Components.MechanicalStructure\">MechanicalStructure</a> from the Modelica Standard Library, with added visualization components.
</p><h2 class=\"legal\"> <a href=\"#\" onclick=\"
   if(document.getElementById('legalSection').style.display == 'none'){
   document.getElementById('legalSection').style.display = 'block';
   document.getElementById('showlegalSection').style.display = 'none';
   document.getElementById('hidelegalSection').style.display = 'inline';
   } else {
   document.getElementById('legalSection').style.display = 'none';
   document.getElementById('showlegalSection').style.display = 'inline';
   document.getElementById('hidelegalSection').style.display = 'none';
   };
   return false;\" style=\"text-decoration: inherit; color: inherit\"><img src=\"./DocumentationFiles/showhide2.png\" alt=\"Show\" id=\"showlegalSection\" style=\"display: inline; vertical-align: text-bottom;\" /><img src=\"./DocumentationFiles/showhide.png\" alt=\"Hide\" id=\"hidelegalSection\" style=\"display: none; vertical-align: text-bottom;\" />Terms and Conditions of Use</a> </h2>
    <span id=\"legalSection\" style=\"display: none;\"><p class=\"legallarge\">
This domain example is an informational resource made freely available by Wolfram Research.
</p><h3 class=\"legal\">Use of This Example</h3>
    <span id=\"legalSection\" style=\"display: block;\"><ul class=\"legal\"><li>You may not use this example for any purpose that is unlawful or dangerous.</li><li>You assume total responsibility and risk for your use of this example.</li><li>You may not present this example with any alteration to its trade dress, trademarks, or design.</li></ul></span><h3 class=\"legal\">License</h3>
    <span id=\"legalSection\" style=\"display: block;\"><p class=\"legalsmall\">
All content in this bundle is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 3.0 Unported License. By accessing the content or using it in any way, you accept and agree to be bound by the terms of this license. If you do not agree to these Terms of Use, you may not use this content. Wolfram Research reserves the right to change, modify, add to, or remove portions of these Terms of Use at any time without notice. Please refer back to <a href=\"http://www.wolfram.com\">www.wolfram.com</a> for the latest Terms of Use.
</p><p class=\"legalsmall\">
A summary of the licensing terms can be found at:<br>
        <a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0\">http://creativecommons.org/licenses/by-nc-sa/3.0</a>
</p><p class=\"legalsmall\">
The full legal code can be found at:<br>
        <a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode\">http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode</a>
</p></span></span><div class=\"legalend\">&nbsp;</div>
   </body>
   <!--WSMINSERTIONTAGEND MechanicalStructure --></html>", revisions = ""), Icon(coordinateSystem(preserveAspectRatio = true, extent = {{-200, -200}, {200, 200}}, grid = {2, 2}, initialScale = 0.1), graphics = {Rectangle(visible = true, fillColor = {192, 192, 192}, fillPattern = FillPattern.Solid, extent = {{-200, -200}, {200, 200}}), Text(visible = true, textColor = {0, 0, 255}, extent = {{-200, 200}, {200, 280}}, textString = "%name", fontName = "Arial"), Text(visible = true, origin = {0, 20}, textColor = {0, 0, 255}, extent = {{-200, -190}, {-140, -150}}, textString = "1", fontName = "Arial"), Text(visible = true, origin = {0, 20}, textColor = {0, 0, 255}, extent = {{-200, -70}, {-140, -30}}, textString = "3", fontName = "Arial"), Text(visible = true, origin = {0, 20}, textColor = {0, 0, 255}, extent = {{-200, -130}, {-140, -90}}, textString = "2", fontName = "Arial"), Text(visible = true, origin = {0, 20}, textColor = {0, 0, 255}, extent = {{-200, 50}, {-140, 90}}, textString = "5", fontName = "Arial"), Text(visible = true, origin = {0, 22}, textColor = {0, 0, 255}, extent = {{-200, -12}, {-140, 28}}, textString = "4", fontName = "Arial"), Text(visible = true, origin = {0, 20}, textColor = {0, 0, 255}, extent = {{-198, 110}, {-138, 150}}, textString = "6", fontName = "Arial"), Bitmap(visible = true, fileName = "modelica://IndustrialRobot/DocumentationFiles\robot_kr15.bmp", imageSource = "", extent = {{-130, -195}, {195, 195}})}), Diagram(coordinateSystem(preserveAspectRatio = true, extent = {{-200.0, -200.0}, {200.0, 200.0}}, grid = {10, 10}, initialScale = 0.1)));
    end MechanicalStructure;
    annotation(Documentation(info = "<html><!--WSMINSERTIONTAGSTART Components -->
   <head>
   <style type=\"text/css\">
   
  body {
   padding: 0px;
   margin: 0px;
  }
  
  a {
   color: #cf1d24;
  }
  
  a.target {
   padding-top: 40px;
   margin-top: -40px;
  }
  
  p {
   font-family: arial;
   font-size: 13;
   margin: 9px 40px 5px 40px;
   padding-bottom: 0px;
   color: #555555;
   max-width: 800px;
  }
  
  h1 {
   font-size: 30;
   color: #cf1d24;
   font-weight: bold;
   margin-left: 20px;
   margin-top: 32px;
   margin-bottom: 15px;
   margin-right: 20px;
   padding-top: 0px;
  }
  
  h2 {
   font-size: 20;
   color: #cf1d24;
   font-weight: bold;
   margin-left: 20px;
   margin-right: 20px;
   margin-top: 5px;
   margin-bottom: 9px;
  }
  
  h3 {
   background: url('DocumentationFiles/dingbat3.png') no-repeat 0 0;
   font-size: 14px;
   font-family: helvetica;
   color: #4B4B4B;
   font-weight: bold;
   padding-left: 18px;
   margin-left: 20px;
   margin-right: 20px;
   margin-top: 12px;
   margin-bottom: 8px;
  }
  
  ul {
   font-family: arial;
   font-size: 13;
   margin: 9px 40px 5px 40px;
   padding-bottom: 0px;
   color: #555555;
   max-width: 800px;
   list-style-type: square;
  }
  
  li {
   margin-left: 0px;
   margin-top: 4px;
   margin-bottom: 2px;
   padding-left: 0px;
  }

  div.header {
   background: url('DocumentationFiles/WSMLogo.png') no-repeat 0 0;
   height: 96px;
   margin-top: 35px;
   background-color: #871613;
  }
  
  .headerspan {
   font-family: arial;
   text-decoration: none;
   font-size: 12px;
   font-weight: bold;
   display: inline-block;
   height: 35px;
   color: gray;
   padding: 0px;
   margin: 0px;
   margin-left: 20px;
  }
  
  .headera {
   font-family: arial;
   text-decoration: none;
   font-size: 12px;
   font-weight: bold;
   padding: 0px;
   color: inherit;
   vertical-align: middle;
   margin: 0px;
  }
  
  .headerlinkdiv {
   background: black;
   padding: 0px;
   height: 35px;
   margin: 0px;
   position: fixed; top: 0px; left: 0px; width: 100%;
  }
  
  .contenttable {
   -webkit-box-shadow: 3px 3px 3px #DDDDDD;
   border-top: 3px solid #cf1d24;
   background: #f9f9f9;
   max-width: 500px;
   margin: 15px 15px 0px 20px;
   padding: 6px 10px 3px 10px;
  }
  
  .contenttableheader {
   color: #a4a4a4;
   font-size: 14px;
   font-family: arial;
  }
  
  .contenttabletable {
   border: 0px solid #FFFFFF;
   padding: 0px;
   padding-left: 20px;
  }
  
  .contenttable tr td {
   padding: 3px;
   min-width: 200px;
  }
  
  .contenttable tr td a {
   color: #555555;
   text-decoration: none;
   font-size: 13px;
   font-family: arial;
  }
  
  .hacek {
   color: #cf1d24;
   font-size: 25px;
   font-weight: plain;
   vertical-align: -40%;
  }
  
  .mathematicapointerwrapper {
   border: 0px solid #DDDDDD;
   margin: 15px 15px 15px 40px;
   padding: 0px;
   max-width: 500px;
  }
  
  .mathematicapointertop {
   border: 1px solid #DDDDDD;
   background-color: #F2F2F2;
   padding: 0px;
   max-width: 500px;
   height: 4px;
  }
  
  .mathematicapointerdiv {
   background: url('./DocumentationFiles/mathematicabook.png') no-repeat  left center;
   border: 1px solid #DDDDDD;
   background-color: #FFFFFF;
   margin: 0px;
   padding: 15px 9px 9px 89px;
   max-width: 500px;
   min-height: 67px;
  }
  
  p.mathematicapointer {
   padding: 0px;
   margin: 0px;
   font-size: 12px;
  }
  
  .infoboxwrapper {
   border: 0px solid #DDDDDD;
   -webkit-box-shadow: 3px 3px 3px #DDDDDD;
   margin: 15px 15px 15px 40px;
   padding: 0px;
   max-width: 500px;
  }
  
  .infoboxtop {
   background: url('./DocumentationFiles/infotick.png') no-repeat left center;
   border: 1px solid #DDDDDD;
   background-color: #F2F2F2;
   padding: 0px;
   max-width: 500px;
   height: 37px;
  }
  
  div.infobox {
   border: 1px solid #DDDDDD;
   background-color: #FFFFFF;
   margin: 0px;
   padding: 15px;
   max-width: 500px;
  }
  
  p.infobox {
   padding: 0px;
   margin: 0px;
   font-size: 12px;
  }
  
  h2.legal {
   font-family: arial;
   font-size: 14;
   color: #cf1d24;
   margin: 15px 15px 15px 20px;
   font-weight: bold;
  }
  
  h3.legal {
   background: url('./DocumentationFiles/dingbat3.png') no-repeat 0 0;
   font-family: arial;
   font-size: 12;
   color: #808080;
   margin-left: 38px;
   padding-left: 12px;
   font-weight: bold;
  }
  
  ul.legal {
   font-size: 10px;
   font-family: arial;
   color: #555555;
   margin-left: 28px;
  }
  
  ul.legal li {
   margin-left: 0px;
   margin-top: 4px;
   margin-bottom: 2px;
   padding-left: 0px;
  }

  ul.imgbullets li {
   margin-left: -40px;
   margin-top: 4px;
   margin-bottom: 10px;
   padding-left: 30px;
   list-style-type: none;
  }
  
  p.legallarge {
   font-size: 12px;
   margin-left: 38px;
  }
  
  p.legalsmall {
   font-size: 11px;
   margin-left: 38px;
   padding-left: 12px;
  }
  
  .legalend {
   height: 10px;
  }
  
  .variablename {
   font-family: Courier New, Courier;
  }
  
  .dialogelement {
   font-weight: bold;
  }
  
  .menuitem {
   font-weight: bold;
  }
  
  .mr {
   font-family: Courier New, Courier;
  }
  
  .ttable {
	border-collapse: collapse;
    width: 100%;
	}

	.ttable td, th {
    border: 1px solid #dddddd;
    text-align: left;
	padding: 8px;
	}

	.ttable tr:nth-child(even) {
		background-color: #dddddd;
	}
  
   </style>
   </head>
   <body>
   
  <div class=\"headerlinkdiv\">
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/examples.png) no-repeat 0 0;
   padding-left: 24px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/examples_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/examples.png) no-repeat 0 0';
   \"><a href=\"https://www.wolfram.com/system-modeler/examples/\" class=\"headera\">More Examples</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/video.png) no-repeat 0 0;
   padding-left: 29px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/video_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/video.png) no-repeat 0 0';
   \"><a href=\"http://www.wolfram.com/system-modeler/resources/get-started/\" class=\"headera\">Introductory Videos</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/docs.png) no-repeat 0 0;
   padding-left: 20px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/docs_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/docs.png) no-repeat 0 0';
   \"><a href=\"http://reference.wolfram.com/system-modeler\" class=\"headera\">Documentation</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/contact.png) no-repeat 0 0;
   padding-left: 24px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/contact_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/contact.png) no-repeat 0 0';
   \"><a href=\"http://www.wolfram.com/system-modeler/contact-us/\" class=\"headera\">Contact Us</a></span>
  </div> <div class=\"header\">&nbsp;</div> <h1>Industrial Robot: Components</h1><a id=\"headerTag_PackageOverview\" class=\"target\">&nbsp;</a>
    <h2>Package Overview</h2>
    <p class=\"\">
This package contains custom components used in the <a href=\"modelica://IndustrialRobot.FullRobot\">main model</a>.
</p><ul></ul><h2 class=\"legal\"> <a href=\"#\" onclick=\"
   if(document.getElementById('legalSection').style.display == 'none'){
   document.getElementById('legalSection').style.display = 'block';
   document.getElementById('showlegalSection').style.display = 'none';
   document.getElementById('hidelegalSection').style.display = 'inline';
   } else {
   document.getElementById('legalSection').style.display = 'none';
   document.getElementById('showlegalSection').style.display = 'inline';
   document.getElementById('hidelegalSection').style.display = 'none';
   };
   return false;\" style=\"text-decoration: inherit; color: inherit\"><img src=\"./DocumentationFiles/showhide2.png\" alt=\"Show\" id=\"showlegalSection\" style=\"display: inline; vertical-align: text-bottom;\" /><img src=\"./DocumentationFiles/showhide.png\" alt=\"Hide\" id=\"hidelegalSection\" style=\"display: none; vertical-align: text-bottom;\" />Terms and Conditions of Use</a> </h2>
    <span id=\"legalSection\" style=\"display: none;\"><p class=\"legallarge\">
This domain example is an informational resource made freely available by Wolfram Research.
</p><h3 class=\"legal\">Use of This Example</h3>
    <span id=\"legalSection\" style=\"display: block;\"><ul class=\"legal\"><li>You may not use this example for any purpose that is unlawful or dangerous.</li><li>You assume total responsibility and risk for your use of this example.</li><li>You may not present this example with any alteration to its trade dress, trademarks, or design.</li></ul></span><h3 class=\"legal\">License</h3>
    <span id=\"legalSection\" style=\"display: block;\"><p class=\"legalsmall\">
All content in this bundle is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 3.0 Unported License. By accessing the content or using it in any way, you accept and agree to be bound by the terms of this license. If you do not agree to these Terms of Use, you may not use this content. Wolfram Research reserves the right to change, modify, add to, or remove portions of these Terms of Use at any time without notice. Please refer back to <a href=\"http://www.wolfram.com\">www.wolfram.com</a> for the latest Terms of Use.
</p><p class=\"legalsmall\">
A summary of the licensing terms can be found at:<br>
        <a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0\">http://creativecommons.org/licenses/by-nc-sa/3.0</a>
</p><p class=\"legalsmall\">
The full legal code can be found at:<br>
        <a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode\">http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode</a>
</p></span></span><div class=\"legalend\">&nbsp;</div>
   </body>
   <!--WSMINSERTIONTAGEND Components --></html>", revisions = ""));
  end Components;

  model FullRobot "6 degree of freedom robot with path planning, controllers, motors, brakes, gears and mechanics."
    import SI = Modelica.SIunits;
    parameter SI.Mass mLoad(min = 0) = 15 "Mass of load";
    parameter SI.Position rLoad[3] = {0.1, 0.25, 0.1} "Distance from last flange to load mass";
    parameter SI.Acceleration g = 9.81 "Gravity acceleration";
    parameter SI.Time refStartTime = 0 "Start time of reference motion";
    parameter SI.Time refSwingTime = 0.5 "Additional time after reference motion is in rest before simulation is stopped";
    parameter Real startAngle1(unit = "deg") = 0 "Start angle of axis 1" annotation(Dialog(tab = "Reference", group = "startAngles"));
    parameter Real startAngle2(unit = "deg") = 60.0 "Start angle of axis 2" annotation(Dialog(tab = "Reference", group = "startAngles"));
    parameter Real startAngle3(unit = "deg") = 90 "Start angle of axis 3" annotation(Dialog(tab = "Reference", group = "startAngles"));
    parameter Real startAngle4(unit = "deg") = 0 "Start angle of axis 4" annotation(Dialog(tab = "Reference", group = "startAngles"));
    parameter Real startAngle5(unit = "deg") = 90 "Start angle of axis 5" annotation(Dialog(tab = "Reference", group = "startAngles"));
    parameter Real startAngle6(unit = "deg") = 45 "Start angle of axis 6" annotation(Dialog(tab = "Reference", group = "startAngles"));
    parameter Real endAngle1(unit = "deg") = 120 "End angle of axis 1" annotation(Dialog(tab = "Reference", group = "endAngles"));
    parameter Real endAngle2(unit = "deg") = 20 "End angle of axis 2" annotation(Dialog(tab = "Reference", group = "endAngles"));
    parameter Real endAngle3(unit = "deg") = 60.0 "End angle of axis 3" annotation(Dialog(tab = "Reference", group = "endAngles"));
    parameter Real endAngle4(unit = "deg") = 0 "End angle of axis 4" annotation(Dialog(tab = "Reference", group = "endAngles"));
    parameter Real endAngle5(unit = "deg") = 0 "End angle of axis 5" annotation(Dialog(tab = "Reference", group = "endAngles"));
    parameter Real endAngle6(unit = "deg") = 90 "End angle of axis 6" annotation(Dialog(tab = "Reference", group = "endAngles"));
    parameter SI.AngularVelocity refSpeedMax[6] = {2, 1.5, 5, 3.1, 3.1, 4.1} "Maximum reference speeds of all joints" annotation(Dialog(tab = "Reference", group = "Limits"));
    parameter SI.AngularAcceleration refAccMax[6] = {15, 15, 15, 60, 60, 60} "Maximum reference accelerations of all joints" annotation(Dialog(tab = "Reference", group = "Limits"));
    parameter Real kp1 = 5 "Gain of position controller" annotation(Dialog(tab = "Controller", group = "Axis 1"));
    parameter Real ks1 = 0.5 "Gain of speed controller" annotation(Dialog(tab = "Controller", group = "Axis 1"));
    parameter SI.Time Ts1 = 0.05 "Time constant of integrator of speed controller" annotation(Dialog(tab = "Controller", group = "Axis 1"));
    parameter Real kp2 = 5 "Gain of position controller" annotation(Dialog(tab = "Controller", group = "Axis 2"));
    parameter Real ks2 = 0.5 "Gain of speed controller" annotation(Dialog(tab = "Controller", group = "Axis 2"));
    parameter SI.Time Ts2 = 0.05 "Time constant of integrator of speed controller" annotation(Dialog(tab = "Controller", group = "Axis 2"));
    parameter Real kp3 = 5 "Gain of position controller" annotation(Dialog(tab = "Controller", group = "Axis 3"));
    parameter Real ks3 = 0.5 "Gain of speed controller" annotation(Dialog(tab = "Controller", group = "Axis 3"));
    parameter SI.Time Ts3 = 0.05 "Time constant of integrator of speed controller" annotation(Dialog(tab = "Controller", group = "Axis 3"));
    parameter Real kp4 = 5 "Gain of position controller" annotation(Dialog(tab = "Controller", group = "Axis 4"));
    parameter Real ks4 = 0.5 "Gain of speed controller" annotation(Dialog(tab = "Controller", group = "Axis 4"));
    parameter SI.Time Ts4 = 0.05 "Time constant of integrator of speed controller" annotation(Dialog(tab = "Controller", group = "Axis 4"));
    parameter Real kp5 = 5 "Gain of position controller" annotation(Dialog(tab = "Controller", group = "Axis 5"));
    parameter Real ks5 = 0.5 "Gain of speed controller" annotation(Dialog(tab = "Controller", group = "Axis 5"));
    parameter SI.Time Ts5 = 0.05 "Time constant of integrator of speed controller" annotation(Dialog(tab = "Controller", group = "Axis 5"));
    parameter Real kp6 = 5 "Gain of position controller" annotation(Dialog(tab = "Controller", group = "Axis 6"));
    parameter Real ks6 = 0.5 "Gain of speed controller" annotation(Dialog(tab = "Controller", group = "Axis 6"));
    parameter SI.Time Ts6 = 0.05 "Time constant of integrator of speed controller" annotation(Dialog(tab = "Controller", group = "Axis 6"));
    IndustrialRobot.Components.MechanicalStructure mechanics(mLoad = mLoad, rLoad = rLoad, g = g) annotation(Placement(transformation(extent = {{35, -35}, {95, 25}}, rotation = 0, origin = {-15, 5}), visible = true));
    Modelica.Mechanics.MultiBody.Examples.Systems.RobotR3.Components.PathPlanning6 pathPlanning(naxis = 6, angleBegDeg = {startAngle1, startAngle2, startAngle3, startAngle4, startAngle5, startAngle6}, angleEndDeg = {endAngle1, endAngle2, endAngle3, endAngle4, endAngle5, endAngle6}, speedMax = refSpeedMax, accMax = refAccMax, startTime = refStartTime, swingTime = refSwingTime) annotation(Placement(transformation(extent = {{-25, -75}, {-5, -55}}, rotation = -180, origin = {-55, 15}), visible = true));
    Modelica.Mechanics.MultiBody.Examples.Systems.RobotR3.Components.AxisType1 axis1(w = 4590, ratio = -105, c = 43, cd = 0.005, Rv0 = 0.4, Rv1 = 0.13 / 160, kp = kp1, ks = ks1, Ts = Ts1) annotation(Placement(transformation(extent = {{-25, -75}, {-5, -55}}, rotation = 0, origin = {-15, 15}), visible = true));
    Modelica.Mechanics.MultiBody.Examples.Systems.RobotR3.Components.AxisType1 axis2(w = 5500, ratio = 210, c = 8, cd = 0.01, Rv1 = 0.1 / 130, Rv0 = 0.5, kp = kp2, ks = ks2, Ts = Ts2) annotation(Placement(transformation(extent = {{-25, -55}, {-5, -35}}, rotation = 0, origin = {-15, 15}), visible = true));
    Modelica.Mechanics.MultiBody.Examples.Systems.RobotR3.Components.AxisType1 axis3(w = 5500, ratio = 60, c = 58, cd = 0.04, Rv0 = 0.7, Rv1 = 0.2 / 130, kp = kp3, ks = ks3, Ts = Ts3) annotation(Placement(transformation(extent = {{-25, -35}, {-5, -15}}, rotation = 0, origin = {-15, 15}), visible = true));
    Modelica.Mechanics.MultiBody.Examples.Systems.RobotR3.Components.AxisType2 axis4(k = 0.2365, w = 6250, D = 0.55, J = 0.00016, ratio = -99, Rv0 = 21.8, Rv1 = 9.8, peak = 26.7 / 21.8, kp = kp4, ks = ks4, Ts = Ts4) annotation(Placement(transformation(extent = {{-25, -15}, {-5, 5}}, rotation = 0, origin = {-15, 15}), visible = true));
    Modelica.Mechanics.MultiBody.Examples.Systems.RobotR3.Components.AxisType2 axis5(k = 0.2608, w = 6250, D = 0.55, J = 0.00018, ratio = 79.2, Rv0 = 30.1, Rv1 = 0.03, peak = 39.6 / 30.1, kp = kp5, ks = ks5, Ts = Ts5) annotation(Placement(transformation(extent = {{-25, 5}, {-5, 25}}, rotation = 0, origin = {-15, 15}), visible = true));
    Modelica.Mechanics.MultiBody.Examples.Systems.RobotR3.Components.AxisType2 axis6(k = 0.0842, w = 7400, D = 0.27, J = 4.3e-05, ratio = -99, Rv0 = 10.9, Rv1 = 3.92, peak = 16.8 / 10.9, kp = kp6, ks = ks6, Ts = Ts6) annotation(Placement(transformation(extent = {{-25, 25}, {-5, 45}}, rotation = 0, origin = {-15, 15}), visible = true));
  protected
    Modelica.Mechanics.MultiBody.Examples.Systems.RobotR3.Components.ControlBus controlBus annotation(Placement(transformation(origin = {-80, 0}, extent = {{-20, -20}, {20, 20}}, rotation = 90), visible = true));
  equation
    connect(controlBus, pathPlanning.controlBus) annotation(Line(visible = true, origin = {-70, 53.333}, points = {{-10, -53.333}, {-10, 26.667}, {20, 26.667}}, color = {255, 204, 51}, thickness = 0.5));
    connect(controlBus.axisControlBus1, axis1.axisControlBus) annotation(Line(visible = true, points = {{-13.333, 33.333}, {-3.333, 33.333}, {-3.333, -16.667}, {26.667, -16.667}}, color = {255, 204, 51}, thickness = 0.5, origin = {-66.667, -33.333}));
    connect(axis1.flange, mechanics.axis1) annotation(Line(visible = true, points = {{-24.625, -13.75}, {5.375, -13.75}, {5.375, 13.75}, {13.875, 13.75}}, origin = {4.625, -36.25}, color = {64, 64, 64}));
    connect(axis2.flange, mechanics.axis2) annotation(Line(visible = true, points = {{-19.625, -8.25}, {0.375, -8.25}, {0.375, 8.25}, {18.875, 8.25}}, origin = {-0.375, -21.75}, color = {64, 64, 64}));
    connect(axis3.flange, mechanics.axis3) annotation(Line(visible = true, points = {{-14.625, -2.75}, {-4.625, -2.75}, {-4.625, 2.75}, {23.875, 2.75}}, origin = {-5.375, -7.25}, color = {64, 64, 64}));
    connect(axis4.flange, mechanics.axis4) annotation(Line(visible = true, points = {{-19.625, 2.75}, {-9.625, 2.75}, {-9.625, -2.75}, {18.875, -2.75}}, origin = {-0.375, 7.25}, color = {64, 64, 64}));
    connect(axis5.flange, mechanics.axis5) annotation(Line(visible = true, points = {{-19.625, 8.25}, {0.375, 8.25}, {0.375, -8.25}, {18.875, -8.25}}, origin = {-0.375, 21.75}, color = {64, 64, 64}));
    connect(axis6.flange, mechanics.axis6) annotation(Line(visible = true, points = {{-24.625, 13.75}, {5.375, 13.75}, {5.375, -13.75}, {13.875, -13.75}}, origin = {4.625, 36.25}, color = {64, 64, 64}));
    connect(controlBus.axisControlBus2, axis2.axisControlBus) annotation(Line(visible = true, points = {{-20, 15}, {0, 15}, {0, -15}, {20, -15}}, color = {255, 204, 51}, thickness = 0.5, origin = {-60, -15}));
    connect(controlBus.axisControlBus3, axis3.axisControlBus) annotation(Line(visible = true, points = {{-25, 5}, {5, 5}, {5, -5}, {15, -5}}, color = {255, 204, 51}, thickness = 0.5, origin = {-55, -5}));
    connect(controlBus.axisControlBus4, axis4.axisControlBus) annotation(Line(visible = true, points = {{-25, -5}, {5, -5}, {5, 5}, {15, 5}}, color = {255, 204, 51}, thickness = 0.5, origin = {-55, 5}));
    connect(controlBus.axisControlBus5, axis5.axisControlBus) annotation(Line(visible = true, points = {{-20, -15}, {0, -15}, {0, 15}, {20, 15}}, color = {255, 204, 51}, thickness = 0.5, origin = {-60, 15}));
    connect(controlBus.axisControlBus6, axis6.axisControlBus) annotation(Line(visible = true, points = {{-16.667, -33.333}, {-6.667, -33.333}, {-6.667, 16.667}, {23.333, 16.667}}, color = {255, 204, 51}, thickness = 0.5, origin = {-63.333, 33.333}));
    annotation(__Wolfram_useDSS = true, Diagram(coordinateSystem(preserveAspectRatio = true, extent = {{-100.0, -100.0}, {100.0, 100.0}}, grid = {10, 10}, initialScale = 0.1)), Icon(coordinateSystem(preserveAspectRatio = true, extent = {{-100, -100}, {100, 100}}, grid = {0.5, 0.5}, initialScale = 0.1), graphics = {Rectangle(visible = true, fillColor = {192, 192, 192}, fillPattern = FillPattern.Solid, extent = {{-99.5, -100}, {100, 100}}), Bitmap(visible = true, fileName = "modelica://IndustrialRobot/DocumentationFiles/robot_kr15.bmp", imageSource = "", extent = {{-75.5, -96.75}, {87, 98.25}}), Text(visible = true, textColor = {0, 0, 255}, extent = {{-111.5, 100}, {108.5, 130}}, textString = "%name", fontName = "Arial"), Text(visible = true, extent = {{-104.5, -128}, {115, -104}}, textString = "mLoad=%mLoad", fontName = "Arial")}), Documentation(info = "<html><!--WSMINSERTIONTAGSTART RobotModelDocumentation -->
   <head>
   <style type=\"text/css\">
   
  body {
   padding: 0px;
   margin: 0px;
  }
  
  a {
   color: #cf1d24;
  }
  
  a.target {
   padding-top: 40px;
   margin-top: -40px;
  }
  
  p {
   font-family: arial;
   font-size: 13;
   margin: 9px 40px 5px 40px;
   padding-bottom: 0px;
   color: #555555;
   max-width: 800px;
  }
  
  h1 {
   font-size: 30;
   color: #cf1d24;
   font-weight: bold;
   margin-left: 20px;
   margin-top: 32px;
   margin-bottom: 15px;
   margin-right: 20px;
   padding-top: 0px;
  }
  
  h2 {
   font-size: 20;
   color: #cf1d24;
   font-weight: bold;
   margin-left: 20px;
   margin-right: 20px;
   margin-top: 5px;
   margin-bottom: 9px;
  }
  
  h3 {
   background: url('DocumentationFiles/dingbat3.png') no-repeat 0 0;
   font-size: 14px;
   font-family: helvetica;
   color: #4B4B4B;
   font-weight: bold;
   padding-left: 18px;
   margin-left: 20px;
   margin-right: 20px;
   margin-top: 12px;
   margin-bottom: 8px;
  }
  
  ul {
   font-family: arial;
   font-size: 13;
   margin: 9px 40px 5px 40px;
   padding-bottom: 0px;
   color: #555555;
   max-width: 800px;
   list-style-type: square;
  }
  
  li {
   margin-left: 0px;
   margin-top: 4px;
   margin-bottom: 2px;
   padding-left: 0px;
  }

  div.header {
   background: url('DocumentationFiles/WSMLogo.png') no-repeat 0 0;
   height: 96px;
   margin-top: 35px;
   background-color: #871613;
  }
  
  .headerspan {
   font-family: arial;
   text-decoration: none;
   font-size: 12px;
   font-weight: bold;
   display: inline-block;
   height: 35px;
   color: gray;
   padding: 0px;
   margin: 0px;
   margin-left: 20px;
  }
  
  .headera {
   font-family: arial;
   text-decoration: none;
   font-size: 12px;
   font-weight: bold;
   padding: 0px;
   color: inherit;
   vertical-align: middle;
   margin: 0px;
  }
  
  .headerlinkdiv {
   background: black;
   padding: 0px;
   height: 35px;
   margin: 0px;
   position: fixed; top: 0px; left: 0px; width: 100%;
  }
  
  .contenttable {
   -webkit-box-shadow: 3px 3px 3px #DDDDDD;
   border-top: 3px solid #cf1d24;
   background: #f9f9f9;
   max-width: 500px;
   margin: 15px 15px 0px 20px;
   padding: 6px 10px 3px 10px;
  }
  
  .contenttableheader {
   color: #a4a4a4;
   font-size: 14px;
   font-family: arial;
  }
  
  .contenttabletable {
   border: 0px solid #FFFFFF;
   padding: 0px;
   padding-left: 20px;
  }
  
  .contenttable tr td {
   padding: 3px;
   min-width: 200px;
  }
  
  .contenttable tr td a {
   color: #555555;
   text-decoration: none;
   font-size: 13px;
   font-family: arial;
  }
  
  .hacek {
   color: #cf1d24;
   font-size: 25px;
   font-weight: plain;
   vertical-align: -40%;
  }
  
  .mathematicapointerwrapper {
   border: 0px solid #DDDDDD;
   margin: 15px 15px 15px 40px;
   padding: 0px;
   max-width: 500px;
  }
  
  .mathematicapointertop {
   border: 1px solid #DDDDDD;
   background-color: #F2F2F2;
   padding: 0px;
   max-width: 500px;
   height: 4px;
  }
  
  .mathematicapointerdiv {
   background: url('./DocumentationFiles/mathematicabook.png') no-repeat  left center;
   border: 1px solid #DDDDDD;
   background-color: #FFFFFF;
   margin: 0px;
   padding: 15px 9px 9px 89px;
   max-width: 500px;
   min-height: 67px;
  }
  
  p.mathematicapointer {
   padding: 0px;
   margin: 0px;
   font-size: 12px;
  }
  
  .infoboxwrapper {
   border: 0px solid #DDDDDD;
   -webkit-box-shadow: 3px 3px 3px #DDDDDD;
   margin: 15px 15px 15px 40px;
   padding: 0px;
   max-width: 500px;
  }
  
  .infoboxtop {
   background: url('./DocumentationFiles/infotick.png') no-repeat left center;
   border: 1px solid #DDDDDD;
   background-color: #F2F2F2;
   padding: 0px;
   max-width: 500px;
   height: 37px;
  }
  
  div.infobox {
   border: 1px solid #DDDDDD;
   background-color: #FFFFFF;
   margin: 0px;
   padding: 15px;
   max-width: 500px;
  }
  
  p.infobox {
   padding: 0px;
   margin: 0px;
   font-size: 12px;
  }
  
  h2.legal {
   font-family: arial;
   font-size: 14;
   color: #cf1d24;
   margin: 15px 15px 15px 20px;
   font-weight: bold;
  }
  
  h3.legal {
   background: url('./DocumentationFiles/dingbat3.png') no-repeat 0 0;
   font-family: arial;
   font-size: 12;
   color: #808080;
   margin-left: 38px;
   padding-left: 12px;
   font-weight: bold;
  }
  
  ul.legal {
   font-size: 10px;
   font-family: arial;
   color: #555555;
   margin-left: 28px;
  }
  
  ul.legal li {
   margin-left: 0px;
   margin-top: 4px;
   margin-bottom: 2px;
   padding-left: 0px;
  }

  ul.imgbullets li {
   margin-left: -40px;
   margin-top: 4px;
   margin-bottom: 10px;
   padding-left: 30px;
   list-style-type: none;
  }
  
  p.legallarge {
   font-size: 12px;
   margin-left: 38px;
  }
  
  p.legalsmall {
   font-size: 11px;
   margin-left: 38px;
   padding-left: 12px;
  }
  
  .legalend {
   height: 10px;
  }
  
  .variablename {
   font-family: Courier New, Courier;
  }
  
  .dialogelement {
   font-weight: bold;
  }
  
  .menuitem {
   font-weight: bold;
  }
  
  .mr {
   font-family: Courier New, Courier;
  }
  
  .ttable {
	border-collapse: collapse;
    width: 100%;
	}

	.ttable td, th {
    border: 1px solid #dddddd;
    text-align: left;
	padding: 8px;
	}

	.ttable tr:nth-child(even) {
		background-color: #dddddd;
	}
  
   </style>
   </head>
   <body>
   
  <div class=\"headerlinkdiv\">
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/examples.png) no-repeat 0 0;
   padding-left: 24px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/examples_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/examples.png) no-repeat 0 0';
   \"><a href=\"https://www.wolfram.com/system-modeler/examples/\" class=\"headera\">More Examples</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/video.png) no-repeat 0 0;
   padding-left: 29px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/video_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/video.png) no-repeat 0 0';
   \"><a href=\"http://www.wolfram.com/system-modeler/resources/get-started/\" class=\"headera\">Introductory Videos</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/docs.png) no-repeat 0 0;
   padding-left: 20px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/docs_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/docs.png) no-repeat 0 0';
   \"><a href=\"http://reference.wolfram.com/system-modeler\" class=\"headera\">Documentation</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/contact.png) no-repeat 0 0;
   padding-left: 24px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/contact_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/contact.png) no-repeat 0 0';
   \"><a href=\"http://www.wolfram.com/system-modeler/contact-us/\" class=\"headera\">Contact Us</a></span>
  </div> <div class=\"header\">&nbsp;</div> <h1>Path Planning and Control of an Industrial Robot</h1><div class=\"contenttable\">
   <span class=\"contenttableheader\">CONTENTS:</span><br/>
   <table class=\"contenttabletable\"><tr><td><a href=\"#\" onClick=\"document.getElementById('headerTag_Introduction').scrollIntoView(); return false;\"><span class=\"hacek\">&#711;</span> Introduction</a></td><td><a href=\"#\" onClick=\"document.getElementById('headerTag_Simulation').scrollIntoView(); return false;\"><span class=\"hacek\">&#711;</span> Simulation</a></td></tr><tr><td><a href=\"#\" onClick=\"document.getElementById('headerTag_InstantPlotting').scrollIntoView(); return false;\"><span class=\"hacek\">&#711;</span> Instant Plotting</a></td><td><a href=\"#\" onClick=\"document.getElementById('headerTag_Real-TimeSimulation').scrollIntoView(); return false;\"><span class=\"hacek\">&#711;</span> Real-Time Simulation</a></td></tr></table></div><a id=\"headerTag_Introduction\" class=\"target\">&nbsp;</a>
    <h2>Introduction</h2>
    <p class=\"\">
This is a six degrees of freedom robot with path planning, controllers, motors, brakes, gears, and mechanics.
</p><a id=\"headerTag_Simulation\" class=\"target\">&nbsp;</a>
    <h2>Simulation</h2>
    <p class=\"\">
To simulate the robot and view a 3D animation of it, follow the steps below:
</p><ul><li>Click the <img src=\"modelica://IndustrialRobot/DocumentationFiles/simCenter.png\" alt=\"simCenter\"/> button in the top-right corner.</li><li>When the build is finished, click the <span class=\"dialogelement\">Simulate</span> button <img src=\"modelica://IndustrialRobot/DocumentationFiles/simulate.png\" alt=\"simulate\"/>.</li><li>Click the <span class=\"dialogelement\">Animate</span> button <img src=\"modelica://IndustrialRobot/DocumentationFiles/animate.png\" alt=\"animate\"/>.</li></ul><p class=\"\">
<img src=\"modelica://IndustrialRobot/DocumentationFiles/animation.png\" alt=\"animation\"/>
</p><a id=\"headerTag_InstantPlotting\" class=\"target\">&nbsp;</a>
    <h2>Instant Plotting</h2>
    <p class=\"\">
Compare the planned trajectory for one of the robot's axes with the simulated controlled path by plotting their respective variables.
</p><p class=\"\">
To plot the variables, follow the steps below:
</p><ul><li>Simulate the model by clicking the <span class=\"dialogelement\">Simulate</span> button <img src=\"modelica://IndustrialRobot/DocumentationFiles/simulate.png\" alt=\"simulate\"/>.</li></ul><p class=\"\">
A preffered stored plot will automatically be displayed, showing reference speed values for the different axes, as well as the actual speed values. There are multiple stored plots showing only individual axes. Opening the stored plot SpeedOfAxis1(referencevsMeasured), you will see the plot below.
</p><p class=\"\">
<img src=\"modelica://IndustrialRobot/DocumentationFiles/plot.png\" alt=\"plot\"/>
</p><a id=\"headerTag_Real-TimeSimulation\" class=\"target\">&nbsp;</a>
    <h2>Real-Time Simulation</h2>
    <p class=\"\">
It is possible to synchronize the simulation with real time. To do this, click the <span class=\"dialogelement\">Settings</span> tab in <em>Simulation Center</em> and choose the <span class=\"dialogelement\">Synchronize with real-time</span> option.
</p><p class=\"\">
<img src=\"modelica://IndustrialRobot/DocumentationFiles/realtime.jpg\" alt=\"realtime\"/>
</p><h2 class=\"legal\"> <a href=\"#\" onclick=\"
   if(document.getElementById('legalSection').style.display == 'none'){
   document.getElementById('legalSection').style.display = 'block';
   document.getElementById('showlegalSection').style.display = 'none';
   document.getElementById('hidelegalSection').style.display = 'inline';
   } else {
   document.getElementById('legalSection').style.display = 'none';
   document.getElementById('showlegalSection').style.display = 'inline';
   document.getElementById('hidelegalSection').style.display = 'none';
   };
   return false;\" style=\"text-decoration: inherit; color: inherit\"><img src=\"./DocumentationFiles/showhide2.png\" alt=\"Show\" id=\"showlegalSection\" style=\"display: inline; vertical-align: text-bottom;\" /><img src=\"./DocumentationFiles/showhide.png\" alt=\"Hide\" id=\"hidelegalSection\" style=\"display: none; vertical-align: text-bottom;\" />Terms and Conditions of Use</a> </h2>
    <span id=\"legalSection\" style=\"display: none;\"><p class=\"legallarge\">
This domain example is an informational resource made freely available by Wolfram Research.
</p><h3 class=\"legal\">Use of This Example</h3>
    <span id=\"legalSection\" style=\"display: block;\"><ul class=\"legal\"><li>You may not use this example for any purpose that is unlawful or dangerous.</li><li>You assume total responsibility and risk for your use of this example.</li><li>You may not present this example with any alteration to its trade dress, trademarks, or design.</li></ul></span><h3 class=\"legal\">License</h3>
    <span id=\"legalSection\" style=\"display: block;\"><p class=\"legalsmall\">
All content in this bundle is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 3.0 Unported License. By accessing the content or using it in any way, you accept and agree to be bound by the terms of this license. If you do not agree to these Terms of Use, you may not use this content. Wolfram Research reserves the right to change, modify, add to, or remove portions of these Terms of Use at any time without notice. Please refer back to <a href=\"http://www.wolfram.com\">www.wolfram.com</a> for the latest Terms of Use.
</p><p class=\"legalsmall\">
A summary of the licensing terms can be found at:<br>
        <a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0\">http://creativecommons.org/licenses/by-nc-sa/3.0</a>
</p><p class=\"legalsmall\">
The full legal code can be found at:<br>
        <a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode\">http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode</a>
</p></span></span><div class=\"legalend\">&nbsp;</div>
   </body>
   <!--WSMINSERTIONTAGEND RobotModelDocumentation --></html>", revisions = ""), experiment(StartTime = 0.0, StopTime = 2, NumberOfIntervals = 500, __Wolfram_Algorithm = "cvodes", Tolerance = 1e-05, __Wolfram_SynchronizeWithRealTime = false), __Wolfram(PlotSet(plots = {Plot(name = "AxisAngles", preferred = true, subPlots = {SubPlot(curves = {Curve(x = time, y = pathPlanning.controlBus.axisControlBus1.angle, legend = "Axis 1"), Curve(x = time, y = pathPlanning.controlBus.axisControlBus2.angle, legend = "Axis 2"), Curve(x = time, y = pathPlanning.controlBus.axisControlBus3.angle, legend = "Axis 3"), Curve(x = time, y = pathPlanning.controlBus.axisControlBus4.angle, legend = "Axis 4"), Curve(x = time, y = pathPlanning.controlBus.axisControlBus5.angle, legend = "Axis 5"), Curve(x = time, y = pathPlanning.controlBus.axisControlBus6.angle, legend = "Axis 6")})}), Plot(name = "AngularVelocities", preferred = true, subPlots = {SubPlot(curves = {Curve(x = time, y = pathPlanning.controlBus.axisControlBus1.speed, legend = "Axis 1"), Curve(x = time, y = pathPlanning.controlBus.axisControlBus2.speed, legend = "Axis 2"), Curve(x = time, y = pathPlanning.controlBus.axisControlBus3.speed, legend = "Axis 3"), Curve(x = time, y = pathPlanning.controlBus.axisControlBus4.speed, legend = "Axis 4"), Curve(x = time, y = pathPlanning.controlBus.axisControlBus5.speed, legend = "Axis 5"), Curve(x = time, y = pathPlanning.controlBus.axisControlBus6.speed, legend = "Axis 6")})}), Plot(name = "AngularAccelerations", subPlots = {SubPlot(curves = {Curve(x = time, y = pathPlanning.controlBus.axisControlBus1.acceleration, legend = "Axis 1"), Curve(x = time, y = pathPlanning.controlBus.axisControlBus2.acceleration, legend = "Axis 2"), Curve(x = time, y = pathPlanning.controlBus.axisControlBus3.acceleration, legend = "Axis 3"), Curve(x = time, y = pathPlanning.controlBus.axisControlBus4.acceleration, legend = "Axis 4"), Curve(x = time, y = pathPlanning.controlBus.axisControlBus5.acceleration, legend = "Axis 5"), Curve(x = time, y = pathPlanning.controlBus.axisControlBus6.acceleration, legend = "Axis 6")})}), Plot(name = "Axis1", group = "AxesVelocityVsReference", subPlots = {SubPlot(curves = {Curve(x = time, y = pathPlanning.controlBus.axisControlBus1.speed, legend = "Angular Velocity"), Curve(x = time, y = pathPlanning.controlBus.axisControlBus1.speed_ref, legend = "Reference")})}), Plot(name = "Axis2", group = "AxesVelocityVsReference", subPlots = {SubPlot(curves = {Curve(x = time, y = pathPlanning.controlBus.axisControlBus2.speed, legend = "Angular Velocity"), Curve(x = time, y = pathPlanning.controlBus.axisControlBus2.speed_ref, legend = "Reference")})}), Plot(name = "Axis3", group = "AxesVelocityVsReference", subPlots = {SubPlot(curves = {Curve(x = time, y = pathPlanning.controlBus.axisControlBus3.speed, legend = "Angular Velocity"), Curve(x = time, y = pathPlanning.controlBus.axisControlBus3.speed_ref, legend = "Reference")})}), Plot(name = "Axis4", group = "AxesVelocityVsReference", subPlots = {SubPlot(curves = {Curve(x = time, y = pathPlanning.controlBus.axisControlBus4.speed, legend = "Angular Velocity"), Curve(x = time, y = pathPlanning.controlBus.axisControlBus4.speed_ref, legend = "Reference")})}), Plot(name = "Axis5", group = "AxesVelocityVsReference", subPlots = {SubPlot(curves = {Curve(x = time, y = pathPlanning.controlBus.axisControlBus5.speed, legend = "Angular Velocity"), Curve(x = time, y = pathPlanning.controlBus.axisControlBus5.speed_ref, legend = "Reference")})}), Plot(name = "Axis6", group = "AxesVelocityVsReference", subPlots = {SubPlot(curves = {Curve(x = time, y = pathPlanning.controlBus.axisControlBus6.speed, legend = "Angular Velocity"), Curve(x = time, y = pathPlanning.controlBus.axisControlBus6.speed_ref, legend = "Reference")})}), Plot(name = "Axis1", group = "AxesAngleVsReference", subPlots = {SubPlot(curves = {Curve(x = time, y = pathPlanning.controlBus.axisControlBus1.angle, legend = "Angle"), Curve(x = time, y = pathPlanning.controlBus.axisControlBus1.angle_ref, legend = "Reference")})}), Plot(name = "Axis2", group = "AxesAngleVsReference", subPlots = {SubPlot(curves = {Curve(x = time, y = pathPlanning.controlBus.axisControlBus2.angle, legend = "Angle"), Curve(x = time, y = pathPlanning.controlBus.axisControlBus2.angle_ref, legend = "Reference")})}), Plot(name = "Axis3", group = "AxesAngleVsReference", subPlots = {SubPlot(curves = {Curve(x = time, y = pathPlanning.controlBus.axisControlBus3.angle, legend = "Angle"), Curve(x = time, y = pathPlanning.controlBus.axisControlBus3.angle_ref, legend = "Reference")})}), Plot(name = "Axis4", group = "AxesAngleVsReference", subPlots = {SubPlot(curves = {Curve(x = time, y = pathPlanning.controlBus.axisControlBus4.angle, legend = "Angle"), Curve(x = time, y = pathPlanning.controlBus.axisControlBus4.angle_ref, legend = "Reference")})}), Plot(name = "Axis5", group = "AxesAngleVsReference", subPlots = {SubPlot(curves = {Curve(x = time, y = pathPlanning.controlBus.axisControlBus5.angle, legend = "Angle"), Curve(x = time, y = pathPlanning.controlBus.axisControlBus5.angle_ref, legend = "Reference")})}), Plot(name = "Axis6", group = "AxesAngleVsReference", subPlots = {SubPlot(curves = {Curve(x = time, y = pathPlanning.controlBus.axisControlBus6.angle, legend = "Angle"), Curve(x = time, y = pathPlanning.controlBus.axisControlBus6.angle_ref, legend = "Reference")})}), Plot(name = "MotorCurrents", subPlots = {SubPlot(curves = {Curve(x = time, y = pathPlanning.controlBus.axisControlBus1.current, legend = "Axis 1"), Curve(x = time, y = pathPlanning.controlBus.axisControlBus2.current, legend = "Axis 2"), Curve(x = time, y = pathPlanning.controlBus.axisControlBus3.current, legend = "Axis 3"), Curve(x = time, y = pathPlanning.controlBus.axisControlBus4.current, legend = "Axis 4"), Curve(x = time, y = pathPlanning.controlBus.axisControlBus5.current, legend = "Axis 5"), Curve(x = time, y = pathPlanning.controlBus.axisControlBus6.current, legend = "Axis 6")})}), Plot(name = "XYPosition", subPlots = {SubPlot(curves = {Curve(x = mechanics.load.frame_b.r_0[1], y = mechanics.load.frame_b.r_0[2], legend = "Load X vs Y Position")})}), Plot(name = "XZPosition", subPlots = {SubPlot(curves = {Curve(x = mechanics.load.frame_b.r_0[1], y = mechanics.load.frame_b.r_0[3], legend = "Load X vs Z Position")})}), Plot(name = "ZYPosition", subPlots = {SubPlot(curves = {Curve(x = mechanics.load.frame_b.r_0[3], y = mechanics.load.frame_b.r_0[2], legend = "Load Z vs Y Position")})})})), preferredView = "info", uses(Modelica(version = "3.2.2")));
  end FullRobot;
  annotation(__Wolfram(openClass = IndustrialRobot.FullRobot, useDocumentationTemplate = false), uses(Modelica(version = "3.2.3")), Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Rectangle(visible = true, lineColor = {111, 0, 0}, fillColor = {255, 0, 0}, fillPattern = FillPattern.HorizontalCylinder, lineThickness = 4, extent = {{-90, -90}, {90, 90}}, radius = 25), Text(visible = true, origin = {12, 20.833}, textColor = {255, 255, 255}, extent = {{-102, -70.833}, {78, 29.167}}, textString = "Ex", fontName = "Arial")}), Documentation(info = "<html><!--WSMINSERTIONTAGSTART RobotPackageDocumentation -->
   <head>
   <style type=\"text/css\">
   
  body {
   padding: 0px;
   margin: 0px;
  }
  
  a {
   color: #cf1d24;
  }
  
  a.target {
   padding-top: 40px;
   margin-top: -40px;
  }
  
  p {
   font-family: arial;
   font-size: 13;
   margin: 9px 40px 5px 40px;
   padding-bottom: 0px;
   color: #555555;
   max-width: 800px;
  }
  
  h1 {
   font-size: 30;
   color: #cf1d24;
   font-weight: bold;
   margin-left: 20px;
   margin-top: 32px;
   margin-bottom: 15px;
   margin-right: 20px;
   padding-top: 0px;
  }
  
  h2 {
   font-size: 20;
   color: #cf1d24;
   font-weight: bold;
   margin-left: 20px;
   margin-right: 20px;
   margin-top: 5px;
   margin-bottom: 9px;
  }
  
  h3 {
   background: url('DocumentationFiles/dingbat3.png') no-repeat 0 0;
   font-size: 14px;
   font-family: helvetica;
   color: #4B4B4B;
   font-weight: bold;
   padding-left: 18px;
   margin-left: 20px;
   margin-right: 20px;
   margin-top: 12px;
   margin-bottom: 8px;
  }
  
  ul {
   font-family: arial;
   font-size: 13;
   margin: 9px 40px 5px 40px;
   padding-bottom: 0px;
   color: #555555;
   max-width: 800px;
   list-style-type: square;
  }
  
  li {
   margin-left: 0px;
   margin-top: 4px;
   margin-bottom: 2px;
   padding-left: 0px;
  }

  div.header {
   background: url('DocumentationFiles/WSMLogo.png') no-repeat 0 0;
   height: 96px;
   margin-top: 35px;
   background-color: #871613;
  }
  
  .headerspan {
   font-family: arial;
   text-decoration: none;
   font-size: 12px;
   font-weight: bold;
   display: inline-block;
   height: 35px;
   color: gray;
   padding: 0px;
   margin: 0px;
   margin-left: 20px;
  }
  
  .headera {
   font-family: arial;
   text-decoration: none;
   font-size: 12px;
   font-weight: bold;
   padding: 0px;
   color: inherit;
   vertical-align: middle;
   margin: 0px;
  }
  
  .headerlinkdiv {
   background: black;
   padding: 0px;
   height: 35px;
   margin: 0px;
   position: fixed; top: 0px; left: 0px; width: 100%;
  }
  
  .contenttable {
   -webkit-box-shadow: 3px 3px 3px #DDDDDD;
   border-top: 3px solid #cf1d24;
   background: #f9f9f9;
   max-width: 500px;
   margin: 15px 15px 0px 20px;
   padding: 6px 10px 3px 10px;
  }
  
  .contenttableheader {
   color: #a4a4a4;
   font-size: 14px;
   font-family: arial;
  }
  
  .contenttabletable {
   border: 0px solid #FFFFFF;
   padding: 0px;
   padding-left: 20px;
  }
  
  .contenttable tr td {
   padding: 3px;
   min-width: 200px;
  }
  
  .contenttable tr td a {
   color: #555555;
   text-decoration: none;
   font-size: 13px;
   font-family: arial;
  }
  
  .hacek {
   color: #cf1d24;
   font-size: 25px;
   font-weight: plain;
   vertical-align: -40%;
  }
  
  .mathematicapointerwrapper {
   border: 0px solid #DDDDDD;
   margin: 15px 15px 15px 40px;
   padding: 0px;
   max-width: 500px;
  }
  
  .mathematicapointertop {
   border: 1px solid #DDDDDD;
   background-color: #F2F2F2;
   padding: 0px;
   max-width: 500px;
   height: 4px;
  }
  
  .mathematicapointerdiv {
   background: url('./DocumentationFiles/mathematicabook.png') no-repeat  left center;
   border: 1px solid #DDDDDD;
   background-color: #FFFFFF;
   margin: 0px;
   padding: 15px 9px 9px 89px;
   max-width: 500px;
   min-height: 67px;
  }
  
  p.mathematicapointer {
   padding: 0px;
   margin: 0px;
   font-size: 12px;
  }
  
  .infoboxwrapper {
   border: 0px solid #DDDDDD;
   -webkit-box-shadow: 3px 3px 3px #DDDDDD;
   margin: 15px 15px 15px 40px;
   padding: 0px;
   max-width: 500px;
  }
  
  .infoboxtop {
   background: url('./DocumentationFiles/infotick.png') no-repeat left center;
   border: 1px solid #DDDDDD;
   background-color: #F2F2F2;
   padding: 0px;
   max-width: 500px;
   height: 37px;
  }
  
  div.infobox {
   border: 1px solid #DDDDDD;
   background-color: #FFFFFF;
   margin: 0px;
   padding: 15px;
   max-width: 500px;
  }
  
  p.infobox {
   padding: 0px;
   margin: 0px;
   font-size: 12px;
  }
  
  h2.legal {
   font-family: arial;
   font-size: 14;
   color: #cf1d24;
   margin: 15px 15px 15px 20px;
   font-weight: bold;
  }
  
  h3.legal {
   background: url('./DocumentationFiles/dingbat3.png') no-repeat 0 0;
   font-family: arial;
   font-size: 12;
   color: #808080;
   margin-left: 38px;
   padding-left: 12px;
   font-weight: bold;
  }
  
  ul.legal {
   font-size: 10px;
   font-family: arial;
   color: #555555;
   margin-left: 28px;
  }
  
  ul.legal li {
   margin-left: 0px;
   margin-top: 4px;
   margin-bottom: 2px;
   padding-left: 0px;
  }

  ul.imgbullets li {
   margin-left: -40px;
   margin-top: 4px;
   margin-bottom: 10px;
   padding-left: 30px;
   list-style-type: none;
  }
  
  p.legallarge {
   font-size: 12px;
   margin-left: 38px;
  }
  
  p.legalsmall {
   font-size: 11px;
   margin-left: 38px;
   padding-left: 12px;
  }
  
  .legalend {
   height: 10px;
  }
  
  .variablename {
   font-family: Courier New, Courier;
  }
  
  .dialogelement {
   font-weight: bold;
  }
  
  .menuitem {
   font-weight: bold;
  }
  
  .mr {
   font-family: Courier New, Courier;
  }
  
  .ttable {
	border-collapse: collapse;
    width: 100%;
	}

	.ttable td, th {
    border: 1px solid #dddddd;
    text-align: left;
	padding: 8px;
	}

	.ttable tr:nth-child(even) {
		background-color: #dddddd;
	}
  
   </style>
   </head>
   <body>
   
  <div class=\"headerlinkdiv\">
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/examples.png) no-repeat 0 0;
   padding-left: 24px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/examples_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/examples.png) no-repeat 0 0';
   \"><a href=\"https://www.wolfram.com/system-modeler/examples/\" class=\"headera\">More Examples</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/video.png) no-repeat 0 0;
   padding-left: 29px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/video_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/video.png) no-repeat 0 0';
   \"><a href=\"http://www.wolfram.com/system-modeler/resources/get-started/\" class=\"headera\">Introductory Videos</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/docs.png) no-repeat 0 0;
   padding-left: 20px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/docs_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/docs.png) no-repeat 0 0';
   \"><a href=\"http://reference.wolfram.com/system-modeler\" class=\"headera\">Documentation</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/contact.png) no-repeat 0 0;
   padding-left: 24px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/contact_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/contact.png) no-repeat 0 0';
   \"><a href=\"http://www.wolfram.com/system-modeler/contact-us/\" class=\"headera\">Contact Us</a></span>
  </div> <div class=\"header\">&nbsp;</div> <h1>Path Planning and Control of an Industrial Robot</h1><a id=\"headerTag_PackageOverview\" class=\"target\">&nbsp;</a>
    <h2>Package Overview</h2>
    <p class=\"\">
This package contains a model of an industrial robot:
</p><ul><li><a href=\"modelica://IndustrialRobot.FullRobot#diagram\">FullRobot</a>: main model of the industrial robot (<a href=\"modelica://IndustrialRobot.FullRobot\">show documentation</a>)</li></ul><p class=\"\">
This example is based on the model in the Modelica Standard Library included with Wolfram SystemModeler.
</p><h2 class=\"legal\"> <a href=\"#\" onclick=\"
   if(document.getElementById('legalSection').style.display == 'none'){
   document.getElementById('legalSection').style.display = 'block';
   document.getElementById('showlegalSection').style.display = 'none';
   document.getElementById('hidelegalSection').style.display = 'inline';
   } else {
   document.getElementById('legalSection').style.display = 'none';
   document.getElementById('showlegalSection').style.display = 'inline';
   document.getElementById('hidelegalSection').style.display = 'none';
   };
   return false;\" style=\"text-decoration: inherit; color: inherit\"><img src=\"./DocumentationFiles/showhide2.png\" alt=\"Show\" id=\"showlegalSection\" style=\"display: inline; vertical-align: text-bottom;\" /><img src=\"./DocumentationFiles/showhide.png\" alt=\"Hide\" id=\"hidelegalSection\" style=\"display: none; vertical-align: text-bottom;\" />Terms and Conditions of Use</a> </h2>
    <span id=\"legalSection\" style=\"display: none;\"><p class=\"legallarge\">
This domain example is an informational resource made freely available by Wolfram Research.
</p><h3 class=\"legal\">Use of This Example</h3>
    <span id=\"legalSection\" style=\"display: block;\"><ul class=\"legal\"><li>You may not use this example for any purpose that is unlawful or dangerous.</li><li>You assume total responsibility and risk for your use of this example.</li><li>You may not present this example with any alteration to its trade dress, trademarks, or design.</li></ul></span><h3 class=\"legal\">License</h3>
    <span id=\"legalSection\" style=\"display: block;\"><p class=\"legalsmall\">
All content in this bundle is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 3.0 Unported License. By accessing the content or using it in any way, you accept and agree to be bound by the terms of this license. If you do not agree to these Terms of Use, you may not use this content. Wolfram Research reserves the right to change, modify, add to, or remove portions of these Terms of Use at any time without notice. Please refer back to <a href=\"http://www.wolfram.com\">www.wolfram.com</a> for the latest Terms of Use.
</p><p class=\"legalsmall\">
A summary of the licensing terms can be found at:<br>
        <a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0\">http://creativecommons.org/licenses/by-nc-sa/3.0</a>
</p><p class=\"legalsmall\">
The full legal code can be found at:<br>
        <a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode\">http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode</a>
</p></span></span><div class=\"legalend\">&nbsp;</div>
   </body>
   <!--WSMINSERTIONTAGEND RobotPackageDocumentation --></html>", revisions = ""));
end IndustrialRobot;